export default Player;
/**
 * This class extends the video.js Player.
 *
 * @class Player
 * @see https://docs.videojs.com/player
 */
declare class Player {
    constructor(tag: any, options: any, ready: any);
    /**
     * A getter/setter for the media's audio track.
     * Activates the audio track according to the language and kind properties.
     * Falls back on the first audio track found if the kind property is not satisfied.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AudioTrack/kind
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AudioTrack/language
     *
     * @param {TrackSelector} [trackSelector]
     *
     * @example
     * // Get the current audio track
     * player.audioTrack();
     *
     * @example
     * // Activate an audio track based on language and kind properties
     * player.audioTrack({language:'en', kind:'description'});
     *
     * @example
     * // Activate first audio track found corresponding to language
     * player.audioTrack({language:'fr'});
     *
     * @return {AudioTrack | undefined} The
     *         currently enabled audio track. See {@link https://docs.videojs.com/audiotrack}.
     */
    audioTrack(trackSelector?: TrackSelector): AudioTrack | undefined;
    /**
     * Calculates an array of ranges based on the `buffered()` data.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/HTMLMediaElement/buffered
     *
     * @returns {Array<{start: number, end: number}>} An array of objects representing start and end points of buffered ranges.
     */
    bufferedRanges(): Array<{
        start: number;
        end: number;
    }>;
    /**
     * Get the percent (as a decimal) of the media that's been played.
     * This method is not a part of the native HTML video API.
     *
     * Live streams with DVR are not currently supported.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/HTMLMediaElement#htmlmediaelement.played
     *
     * @return {number}
     *         A decimal between 0 and 1 representing the percent
     *         that is played 0 being 0% and 1 being 100%
     */
    playedPercent(): number;
    /**
     * Get an array of ranges based on the `played` data.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/HTMLMediaElement#htmlmediaelement.played
     *
     * @returns {Array<{start: number, end: number}>} An array of objects representing start and end points of played ranges.
     */
    playedRanges(): Array<{
        start: number;
        end: number;
    }>;
    /**
     * Calculates an array of ranges based on the `seekable()` data.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/HTMLMediaElement/seekable
     *
     * @returns {Array<{start: number, end: number}>} An array of objects representing start and end points of seekable ranges.
     */
    seekableRanges(): Array<{
        start: number;
        end: number;
    }>;
    /**
     * A getter/setter for the media's text track.
     * Activates the text track according to the language and kind properties.
     * Falls back on the first text track found if the kind property is not satisfied.
     * Disables all subtitle tracks that are `showing` if the `trackSelector` is truthy but does not satisfy any condition.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/TextTrack/kind
     * @see https://developer.mozilla.org/en-US/docs/Web/API/textTrack/language
     *
     * @param {TrackSelector} [trackSelector]
     *
     * @example
     * // Get the current text track
     * player.textTrack();
     *
     * @example
     * // Disable all text tracks has a side effect
     * player.textTrack('off');
     * player.textTrack({});
     *
     * @example
     * // Activate an text track based on language and kind properties
     * player.textTrack({language:'en', kind:'captions'});
     *
     * @example
     * // Activate first text track found corresponding to language
     * player.textTrack({language:'fr'});
     *
     * @return {TextTrack | undefined} The
     *         currently enabled text track. See {@link https://docs.videojs.com/texttrack}.
     */
    textTrack(trackSelector?: TrackSelector): TextTrack | undefined;
}
//# sourceMappingURL=player.d.ts.map