export default MediaComposition;
export type Channel = import('./typedef').Channel;
export type Chapter = import('./typedef').Chapter;
export type Episode = import('./typedef').Episode;
export type Resource = import('./typedef').Resource;
export type Segment = import('./typedef').Segment;
export type Show = import('./typedef').Show;
export type Subtitle = import('./typedef').Subtitle;
export type TimeInterval = import('./typedef').TimeInterval;
export type Topic = import('./typedef').Topic;
export type MainResource = import('./typedef').MainResource;
/**
 * @typedef {import('./typedef').Channel} Channel
 * @typedef {import('./typedef').Chapter} Chapter
 * @typedef {import('./typedef').Episode} Episode
 * @typedef {import('./typedef').Resource} Resource
 * @typedef {import('./typedef').Segment} Segment
 * @typedef {import('./typedef').Show} Show
 * @typedef {import('./typedef').Subtitle} Subtitle
 * @typedef {import('./typedef').TimeInterval} TimeInterval
 * @typedef {import('./typedef').Topic} Topic
 * @typedef {import('./typedef').MainResource} MainResource
 */
/**
 * Represents the composition of media content.
 *
 * @class MediaComposition
 * @property {string} chapterUrn URN (Uniform Resource Name) of the associated chapter.
 * @property {string} segmentUrn URN of the associated segment.
 * @property {Episode} episode Associated episode.
 * @property {Show} show Associated show.
 * @property {Channel} channel Associated channel.
 * @property {Array.<Chapter>} chapterList List of associated chapters.
 * @property {Array.<Topic>} topicList List of associated topics.
 * @property {Object.<String, String>} analyticsData Analytics data associated with the media composition.
 * @property {Object.<String, String>} analyticsMetadata Metadata associated with analytics for the media composition.
 */
declare class MediaComposition {
    /**
     * Find a chapter by its URN.
     *
     * @param {String} urn
     *
     * @returns {Chapter} chapter
     */
    findChapterByUrn(urn: string): Chapter;
    /**
     * Return a segment from main chapter following segmentUrn in mediaComposition.
     *
     * @returns {Segment|undefined} main segment
     */
    findMainSegment(): Segment | undefined;
    /**
     * Find resource list by URN.
     *
     * @param {String} urn
     * @returns {Array.<Resource>|undefined} of resources
     */
    findResourceListByUrn(urn: string): Array<Resource> | undefined;
    /**
     * A list of chapters.
     *
     * @returns {Array.<Chapter>} of chapters
     */
    getChapters(): Array<Chapter>;
    /**
     * Filter external text tracks that are already available internally.
     *
     * __Rules:__
     * 1. TTML format is filtered
     *
     * 2. If both are empty that means only internal text tracks will be displayed
     * to the user as they are automatically loaded by the player.
     *
     * 3. If subtitleInformationList is missing from the MediaComposition and subtitleList
     * is available but the media contains internal text tracks that are also available internally.
     * It will result on a duplication client side.
     *
     * 4. If subtitleList and subtitleInformationList a merge between both will be operated,
     * removing the external text tracks already available internally.
     *
     *
     * @returns {Array.<Subtitle>} external text tracks
     */
    getFilteredExternalSubtitles(): Array<Subtitle>;
    /**
     * Block reason for main chapter. This also uses current date for STARTDATE.
     *
     * @see BlockReason
     *
     * @returns {string | undefined} undefined if main chapter is not blocked
     */
    getMainBlockReason(): string | undefined;
    /**
     * Get blocked segments from the main chapter.
     *
     * @returns {Array.<Segment>} of blocked segments
     */
    getMainBlockedSegments(): Array<Segment>;
    /**
     * Get the mediaComposition's main chapter.
     *
     * @returns {Chapter}
     */
    getMainChapter(): Chapter;
    mainChapter: import("./typedef").Chapter;
    /**
     * Get the main chapter's image URL decorated with default width and format.
     *
     * @returns {String|undefined} image URL
     */
    getMainChapterImageUrl(): string | undefined;
    /**
     * Get main resources.
     *
     * @returns {Array.<MainResource>} array of sources.
     */
    getMainResources(): Array<MainResource>;
    /**
     * Get segments of the main chapter ordered by markIn.
     *
     * @returns {Array.<Segment>} of segments
     */
    getMainSegments(): Array<Segment>;
    mainSegments: import("./typedef").Segment[];
    /**
     * Retrieves an array of time intervals associated with the main chapter.
     *
     * @returns {Array.<TimeInterval>} An array of time intervals.
     */
    getMainTimeIntervals(): Array<TimeInterval>;
    /**
     * Compute a date from which this content is valid. Always return a date object.
     *
     * @returns {Date} date specified in media composition or EPOCH when no date present.
     */
    getMainValidFromDate(): Date;
    /**
     * Get merged analytics data.
     *
     * @param {Object.<string, string>} analyticsData
     * @returns {Object.<string, string>} Merged analytics data.
     */
    getMergedAnalyticsData(analyticsData: {
        [x: string]: string;
    }): {
        [x: string]: string;
    };
    /**
     * Get merged analytics metadata.
     *
     * @param {Object.<string, string>} analyticsMetadata
     * @returns {Object.<string, string>} Merged analytics metadata.
     */
    getMergedAnalyticsMetadata(analyticsMetadata: {
        [x: string]: string;
    }): {
        [x: string]: string;
    };
    /**
     * Get the chapter's resource list
     * @returns {Array.<Resource>} of resources
     */
    getResourceList(): Array<Resource>;
}
//# sourceMappingURL=MediaComposition.d.ts.map