export default PillarboxMonitoring;
/** @import Player from 'video.js/dist/types/player' */
/**
 * The PillarboxMonitoring class retrieves data about media playback.
 *
 * This data can be used to :
 *  - help investigate playback problems
 *  - measure the quality of our service
 *
 * The sending of this data tries to respect as much as possible the
 * specification described in the link below.
 *
 * However, some platforms may have certain limitations.
 * In this case, only the data available will be sent.
 *
 * @see https://github.com/SRGSSR/pillarbox-documentation/blob/main/Specifications/monitoring.md
 */
declare class PillarboxMonitoring {
    /**
     * Returns a string representing the error key combined with its error code.
     *
     * If the error code doesn't exist the error key undefined.
     *
     * @param {number} code The error code
     *
     * @returns {string} The error key combined with its error code
     */
    static errorKeyCode(code: number): string;
    /**
     * Generates a new session ID.
     *
     * @returns {string} random UUID
     */
    static sessionId(): string;
    /**
     * Retrieve or generate a unique device ID and stores it in localStorage.
     *
     * @returns {string|undefined} The device ID if localStorage is available,
     *                             otherwise `undefined`
     */
    static deviceId(): string | undefined;
    /**
     * Generate a cryptographically secure random UUID.
     *
     * @returns {string}
     */
    static randomUUID(): string;
    /**
     * converts seconds into milliseconds.
     *
     * @param {number} seconds
     *
     * @returns {number} milliseconds as an integer value
     */
    static secondsToMilliseconds(seconds: number): number;
    /**
     * The timestamp in milliseconds.
     *
     * @return {number} milliseconds as an integer value
     */
    static timestamp(): number;
    /**
     * The browser's user agent.
     *
     * @returns {string}
     */
    static userAgent(): string;
    /**
     * Creates an instance of PillarboxMonitoring.
     *
     * @constructor
     * @param {Player} player The player instance to be monitored
     * @param {PillarboxMonitoringOptions} [options={}] Configuration options for the monitoring
     * @param {string} [options.playerName='none'] The name of the player
     * @param {string} [options.playerVersion='none'] The version of the player
     * @param {string} [options.platform='Web'] The platform on which the player is running
     * @param {number} [options.schemaVersion=1] The version of the schema used for monitoring
     * @param {number} [options.heartbeatInterval=30000] The interval in milliseconds for sending heartbeat signals
     * @param {string} [options.beaconUrl='https://monitoring.pillarbox.ch/api/events'] The URL for the monitoring beacon
     */
    constructor(player: Player, { playerName, playerVersion, platform, schemaVersion, heartbeatInterval, beaconUrl }?: PillarboxMonitoringOptions);
    /**
     * @type {import('video.js/dist/types/player').default}
     */
    player: import('video.js/dist/types/player').default;
    /**
     * @type {string}
     */
    playerName: string;
    /**
     * @type {string}
     */
    playerVersion: string;
    /**
     * @type {string}
     */
    platform: string;
    /**
     * @type {string}
     */
    schemaVersion: string;
    /**
     * @type {Number}
     */
    heartbeatInterval: number;
    /**
     * @type {string}
     */
    beaconUrl: string;
    /**
     * @type {string}
     */
    currentSessionId: string;
    /**
     * @type {Number}
     */
    lastPlaybackDuration: number;
    /**
     * @type {Number}
     */
    lastPlaybackStartTimestamp: number;
    /**
     * @type {Number}
     */
    lastStallCount: number;
    /**
     * @type {Number}
     */
    lastStallDuration: number;
    /**
     * @type {Number}
     */
    loadStartTimestamp: number;
    /**
     * @type {Number}
     */
    metadataRequestTime: number;
    /**
     * @type {string}
     */
    mediaAssetUrl: string;
    /**
     * @type {string}
     */
    mediaId: string;
    /**
     * @type {string}
     */
    mediaMetadataUrl: string;
    /**
     * @type {string}
     */
    mediaOrigin: string;
    /**
     * @type {Number}
     */
    tokenRequestTime: number;
    /**
     * Adds event listeners to the player and the window.
     */
    addListeners(): void;
    /**
     * The current bandwidth of the last segment download.
     *
     * @returns {number|undefined} The current bandwidth in bits per second,
     *                             undefined otherwise.
     */
    bandwidth(): number | undefined;
    /**
     * Binds the callback functions to the current instance.
     */
    bindCallBacks(): void;
    /**
     * Handles player errors by sending an `ERROR` event, then resets the session.
     */
    error(): void;
    /**
     * Handles the session start by sending a `START` event immediately followed
     * by a `HEARTBEAT` when the `loadeddata` event is triggered.
     */
    loadedData(): void;
    /**
     * Handles `loadstart` event and captures the current timestamp. Will be used
     * to calculate the media loading time.
     */
    loadStart(): void;
    /**
     * Assign the timestamp each time the playback starts.
     */
    playbackStart(): void;
    /**
     * Calculates and accumulates the duration of the playback session each time
     * the playback stops for the current media.
     */
    playbackStop(): void;
    /**
     * Handles the stalled state of the player. Sets the stalled state and listens
     * for the event that indicates the player is no longer stalled.
     */
    stalled(): void;
    /**
     * Stops the current session by sending a `STOP` event and resetting the
     * session.
     *
     * @param {Event} [event] The event that triggered the stop. This is passed
     *                        to the reset function.
     */
    sessionStop(event?: Event): void;
    /**
     * Get the buffer duration in milliseconds.
     *
     * @returns {Number} The buffer duration
     */
    bufferDuration(): number;
    /**
     * Gets the language of the current audio track.
     *
     * @returns {string|undefined} The language of the current audio track, or undefined if no audio track is available or if the language is not set.
     */
    currentAudioTrack(): string | undefined;
    /**
     * Get the current representation when playing a Dash or Hls media.
     *
     * @typedef {Object} Representation
     * @property {number|undefined} bandwidth The bandwidth of the current
     *                                        representation
     * @property {number|undefined} programDateTime The program date time of the
     *                                              current representation
     * @property {string|undefined} uri The URL of the current representation
     *
     * @returns {Representation|undefined} The current representation object
     *                                     undefined otherwise
     */
    currentRepresentation(): {
        /**
         * The bandwidth of the current
         * representation
         */
        bandwidth: number | undefined;
        /**
         * The program date time of the
         * current representation
         */
        programDateTime: number | undefined;
        /**
         * The URL of the current representation
         */
        uri: string | undefined;
    };
    /**
     * Get the current resource information including bitrate and URL when available.
     *
     * @typedef {Object} Resource
     * @property {number|undefined} bitrate The bitrate of the current resource
     * @property {string|undefined} url The URL of the current resource
     *
     * @returns {Resource} The current resource information.
     */
    currentResource(): {
        /**
         * The bitrate of the current resource
         */
        bitrate: number | undefined;
        /**
         * The URL of the current resource
         */
        url: string | undefined;
    };
    /**
     * The media data of the current source.
     *
     * @returns {Object} The media data of the current source, or an empty object
     *                   if no media data is available.
     */
    currentSourceMediaData(): any;
    /**
     * Gets the language of the current text track (subtitles or captions).
     *
     * @returns {string|undefined} The language of the current text track, or undefined if no text track is available or if the language is not set.
     */
    currentTextTrack(): string | undefined;
    /**
     * Get the DRM license request duration from performance API.
     *
     * @returns {number|undefined} The request duration
     */
    getDrmRequestDuration(): number | undefined;
    /**
     * Get metadata information from the performance API for a given id.
     *
     * @typedef {Object} MetadataInfo
     * @property {string} name The URL of the resource
     * @property {number} duration The duration of the resource fetch in milliseconds
     *
     * @param {string} id The id to search for in the resource entries
     *
     * @returns {MetadataInfo|undefined} An object containing metadata
     * information, or undefined otherwise
     */
    getMetadataInfo(id: string): {
        /**
         * The URL of the resource
         */
        name: string;
        /**
         * The duration of the resource fetch in milliseconds
         */
        duration: number;
    };
    /**
     * Get the Akamai token request duration from performance API.
     *
     * @returns {number|undefined} The request duration
     */
    getTokenRequestDuration(tokenType: any): number | undefined;
    /**
     * Send an 'HEARTBEAT' event with the date of the current playback state at
     * regular intervals.
     */
    heartbeat(): void;
    heartbeatIntervalId: NodeJS.Timeout;
    /**
     * Check if the tracker is disabled.
     *
     * @returns {Boolean} __true__ if disabled __false__ otherwise.
     */
    isTrackerDisabled(): boolean;
    sessionStartTimestamp: number;
    /**
     * The media information.
     *
     * @typedef {Object} MediaInfo
     * @property {string} asset_url  The URL of the media
     * @property {string} id  The ID of the media
     * @property {string} metadata_url  The URL of the media metadata
     * @property {string} origin  The origin of the media
     *
     * @returns {MediaInfo} An object container the media information
     */
    mediaInfo(): {
        /**
         * The URL of the media
         */
        asset_url: string;
        /**
         * The ID of the media
         */
        id: string;
        /**
         * The URL of the media metadata
         */
        metadata_url: string;
        /**
         * The origin of the media
         */
        origin: string;
    };
    /**
     * The total playback duration for the current session.
     *
     * @returns {number} The total playback duration in milliseconds.
     */
    playbackDuration(): number;
    /**
     * The current playback position and position timestamp.
     *
     * @typedef {Object} PlaybackPosition
     * @property {number} position The current playback position in milliseconds
     * @property {number|undefined} position_timestamp The timestamp of the
     *                    current playback position, or undefined if not available
     *
     * @returns {PlaybackPosition} The playback position object.
     */
    playbackPosition(): {
        /**
         * The current playback position in milliseconds
         */
        position: number;
        /**
         * The timestamp of the
         * current playback position, or undefined if not available
         */
        position_timestamp: number | undefined;
    };
    /**
     * The current dimensions of the player.
     *
     * @typedef {Object} PlayerCurrentDimensions
     * @property {number} width The current width of the player
     * @property {number} height The current height of the player
     *
     * @returns {PlayerCurrentDimensions} The current dimensions of the player object.
     */
    playerCurrentDimensions(): {
        /**
         * The current width of the player
         */
        width: number;
        /**
         * The current height of the player
         */
        height: number;
    };
    /**
     * Information about the player.
     *
     * @typedef {Object} PlayerInfo
     * @property {string} name The name of the player
     * @property {string} version The version of the player
     * @property {string} platform The platform on which the player is running
     *
     * @returns {PlayerInfo} An object containing player information.
     */
    playerInfo(): {
        /**
         * The name of the player
         */
        name: string;
        /**
         * The version of the player
         */
        version: string;
        /**
         * The platform on which the player is running
         */
        platform: string;
    };
    /**
     * Generates the QoE timings object.
     *
     * @typedef {Object} QoeTimings
     * @property {number} metadata The time taken to load metadata
     * @property {number} asset The time taken to load the asset
     * @property {number} total The total time taken from session start to data load
     *
     * @param {number} timeToLoadedData The time taken to load the data
     * @param {number} timestamp The current timestamp
     *
     * @returns {QoeTimings} The QoE timings
     */
    qoeTimings(timeToLoadedData: number, timestamp: number): {
        /**
         * The time taken to load metadata
         */
        metadata: number;
        /**
         * The time taken to load the asset
         */
        asset: number;
        /**
         * The total time taken from session start to data load
         */
        total: number;
    };
    /**
     * Generates the QoS timings object.
     *
     * @typedef {Object} QosTimings
     * @property {number} asset The time taken to load the asset
     * @property {number} drm The time taken for DRM processing
     * @property {number} metadata The time taken to load metadata
     * @property {number} token The time taken to request the token
     *
     * @param {number} timeToLoadedData The time taken to load the data
     *
     * @returns {QosTimings} The QoS timings
     */
    qosTimings(timeToLoadedData: number): {
        /**
         * The time taken to load the asset
         */
        asset: number;
        /**
         * The time taken for DRM processing
         */
        drm: number;
        /**
         * The time taken to load metadata
         */
        metadata: number;
        /**
         * The time taken to request the token
         */
        token: number;
    };
    /**
     * Removes all event listeners from the player and the window.
     */
    removeListeners(): void;
    /**
     * Remove the token from the asset URL.
     *
     * @param {string} assetUrl The URL of the asset
     *
     * @returns {string|undefined} The URL without the token, or undefined if the
     *                             input URL is invalid
     */
    removeTokenFromAssetUrl(assetUrl: string): string | undefined;
    /**
     * Resets the playback session and clears relevant properties.
     *
     * @param {Event} event The event that triggered the reset. If the event type
     *                 is not 'ended' or 'playerreset', listeners will be removed.
     */
    reset(event: Event): void;
    /**
     * Sends an event to the server using the Beacon API.
     *
     * @param {string} eventName Either START, STOP, ERROR, HEARTBEAT
     * @param {Object} [data={}] The payload object to be sent. Defaults to an
     *                           empty object if not provided
     */
    sendEvent(eventName: string, data?: any): void;
    /**
     * Starts a new session by first stopping the previous session, then resetting
     * the session start timestamp and media ID to their new values.
     */
    sessionStart(): void;
    isStalled: boolean;
    /**
     * Information about the player's stall events.
     *
     * @typedef {Object} StallInfo
     * @property {number} count The number of stall events
     * @property {number} duration The total duration of stall events in
     *                             milliseconds
     *
     * @returns {StallInfo} An object containing the stall information
     */
    stallInfo(): {
        /**
         * The number of stall events
         */
        count: number;
        /**
         * The total duration of stall events in
         * milliseconds
         */
        duration: number;
    };
    /**
     * Get data on the current playback state. Will be used when sending `HEARTBEAT` or `STOP` events.
     *
     * @typedef {Object} StatusEventData
     * @property {number} bandwidth The current bandwidth
     * @property {number|undefined} bitrate The bitrate of the current resource
     * @property {number} buffered_duration The duration of the buffered content
     * @property {number} frame_drops The number of dropped frames
     * @property {number} playback_duration The duration of the playback
     * @property {number} position The current playback position
     * @property {number} position_timestamp The timestamp of the current playback position
     * @property {Object} stall Information about any stalls
     * @property {string} stream_type The type of stream, either 'on-demand' or 'live'
     * @property {string|undefined} url The URL of the current resource
     *
     * @returns {StatusEventData} The current event data
     */
    statusEventData(): {
        /**
         * The current bandwidth
         */
        bandwidth: number;
        /**
         * The bitrate of the current resource
         */
        bitrate: number | undefined;
        /**
         * The duration of the buffered content
         */
        buffered_duration: number;
        /**
         * The number of dropped frames
         */
        frame_drops: number;
        /**
         * The duration of the playback
         */
        playback_duration: number;
        /**
         * The current playback position
         */
        position: number;
        /**
         * The timestamp of the current playback position
         */
        position_timestamp: number;
        /**
         * Information about any stalls
         */
        stall: any;
        /**
         * The type of stream, either 'on-demand' or 'live'
         */
        stream_type: string;
        /**
         * The URL of the current resource
         */
        url: string | undefined;
    };
    /**
     * Generates the data for the start event.
     *
     * @typedef {Object} Device
     * @property {string} id The device ID.
     *
     * @typedef {Object} StartEventData
     * @property {string} browser The user agent string of the browser.
     * @property {Device} device Information about the device.
     * @property {MediaInfo} media Information about the media.
     * @property {PlayerInfo} player Information about the player.
     * @property {QoeTimings} qoe_timings Quality of Experience timings.
     * @property {QosTimings} qos_timings Quality of Service timings.
     * @property {PlayerCurrentDimensions} screen The current dimensions of the
     *                                            player.
     *
     * @returns {StartEventData} An object containing the start event data.
     */
    startEventData(): {
        /**
         * The user agent string of the browser.
         */
        browser: string;
        /**
         * Information about the device.
         */
        device: {
            /**
             * The device ID.
             */
            id: string;
        };
        /**
         * Information about the media.
         */
        media: {
            /**
             * The URL of the media
             */
            asset_url: string;
            /**
             * The ID of the media
             */
            id: string;
            /**
             * The URL of the media metadata
             */
            metadata_url: string;
            /**
             * The origin of the media
             */
            origin: string;
        };
        /**
         * Information about the player.
         */
        player: {
            /**
             * The name of the player
             */
            name: string;
            /**
             * The version of the player
             */
            version: string;
            /**
             * The platform on which the player is running
             */
            platform: string;
        };
        /**
         * Quality of Experience timings.
         */
        qoe_timings: {
            /**
             * The time taken to load metadata
             */
            metadata: number;
            /**
             * The time taken to load the asset
             */
            asset: number;
            /**
             * The total time taken from session start to data load
             */
            total: number;
        };
        /**
         * Quality of Service timings.
         */
        qos_timings: {
            /**
             * The time taken to load the asset
             */
            asset: number;
            /**
             * The time taken for DRM processing
             */
            drm: number;
            /**
             * The time taken to load metadata
             */
            metadata: number;
            /**
             * The time taken to request the token
             */
            token: number;
        };
        /**
         * The current dimensions of the
         * player.
         */
        screen: {
            /**
             * The current width of the player
             */
            width: number;
            /**
             * The current height of the player
             */
            height: number;
        };
    };
}
//# sourceMappingURL=PillarboxMonitoring.d.ts.map